if [ -f /etc/xmp/modules.conf ] && cmp -s /etc/defaults/etc/xmp/modules.conf /etc/xmp/modules.conf
then
    rm /etc/xmp/modules.conf
fi

if [ -f /etc/xmp/xmp.conf ] && cmp -s /etc/defaults/etc/xmp/xmp.conf /etc/xmp/xmp.conf
then
    rm /etc/xmp/xmp.conf
fi

