if [ ! -f /etc/xmp/modules.conf ]
then
    /usr/bin/mkdir -p /etc/xmp
    /usr/bin/cp /etc/defaults/etc/xmp/modules.conf /etc/xmp/modules.conf
fi

if [ ! -f /etc/xmp/xmp.conf ]
then
    /usr/bin/mkdir -p /etc/xmp
    /usr/bin/cp /etc/defaults/etc/xmp/xmp.conf /etc/xmp/xmp.conf
fi

